@@ -8,12 +8,14 @@ var usbDisk2_8py =
     [ "inspectData", "usbDisk2_8py.html#a40f49ea9cccdda381360944bb4694c67", null ],
     [ "print_targets_if_modif", "usbDisk2_8py.html#a9b785d4df1b354b96fff6351c4d228b9", null ],
     [ "safePath", "usbDisk2_8py.html#a1cc978f0b36fc7a494c61860e5cd2a3a", null ],
-    [ "app", "usbDisk2_8py.html#a7b308631a869bff5cf9803b55cafa999", null ],
-    [ "debug", "usbDisk2_8py.html#a9c78a8206ea5af261d02a8d635917f91", null ],
-    [ "dependences", "usbDisk2_8py.html#aea0bbd50bfcf3824a2cdc73daf020866", null ],
+    [ "app", "usbDisk2_8py.html#abca0b8bcb24bdfb2b8443a7ddeb36254", null ],
+    [ "debug", "usbDisk2_8py.html#a9df1fdfc2e7c6f4893a1566c4db759a3", null ],
+    [ "dependances", "usbDisk2_8py.html#a6888ffacbe946e7676339f7fc3696912", null ],
+    [ "level", "usbDisk2_8py.html#a2e93b1fb0e3ca6307812e8f464814155", null ],
     [ "licence", "usbDisk2_8py.html#a535b2d454752927e5e0498f83f699f42", null ],
     [ "licence_en", "usbDisk2_8py.html#a73d793d56af8fd2191b58cdbc239419d", null ],
-    [ "main", "usbDisk2_8py.html#a7732ae2a26b448f16e87768e62dffa76", null ],
-    [ "no_options", "usbDisk2_8py.html#a6e78db3167257d5fc2351d0e75fce37c", null ],
+    [ "machin", "usbDisk2_8py.html#ac2e9157315de37a948920b8ad2acd1ea", null ],
+    [ "main", "usbDisk2_8py.html#a35e8cb05f48405cf17cba03217677439", null ],
+    [ "no_options", "usbDisk2_8py.html#ad2c8a01e0625293a29146b0dcbed4a39", null ],
     [ "not_interesting", "usbDisk2_8py.html#a83c9a8fbdb41f52508949686d997cddc", null ]
 ];
\ No newline at end of file
