@@ -389,7 +389,7 @@ class mainWindow(QMainWindow):
         cmd ="df '%s'" %path
         dfOutput=subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE).communicate()[0]
         dfOutput=str(dfOutput.split(b"\n")[-2])
-        m = re.match("(\S+)\s+(\S+)\s+(\S+)\s+(\S+)\s+(\S+)\s+(\S+).*", dfOutput).groups()
+        m = re.match(r"(\S+)\s+(\S+)\s+(\S+)\s+(\S+)\s+(\S+)\s+(\S+).*", dfOutput).groups()
         return m
 
 
