@@ -6,7 +6,7 @@ python3safe=True
 
 if __name__=="__main__":
     files=os.listdir(".")
-    pattern=re.compile(".*\.py$")
+    pattern=re.compile(r".*\.py$")
     files = [f for f in files if pattern.search(f) and "Ui_" not in f]
     safe=[]
     notsafe=[]
